@@ -1,8 +1,3 @@
-context("footnotes")
-
-library(xml2)
-library(magrittr)
-
 # import files -----
 result_erratum <- "testfiles/erratum.xml" %>%
   jst_get_footnotes()
@@ -29,10 +24,8 @@ test_that("class is correct", {
 
 test_that("extracting footnotes works", {
   expect_identical(result_erratum[["footnotes"]][[1]], NA_character_)
-  expect_known_output(print(result[["footnotes"]]),
-                      "testfiles/correct_footnotes.txt")
-  expect_known_output(print(single_and_multiple_footnotes[["footnotes"]]),
-                      "testfiles/correct_footnotes_mangled.txt")
+  expect_snapshot_output(print(result[["footnotes"]]))
+  expect_snapshot_output(print(single_and_multiple_footnotes[["footnotes"]]))
   expect_identical(footnotes_in_body[[1, "footnotes"]],
                    paste("1Martin Carnoy, “The Costs and Returns to Education",
                          "in Mexico” (PhD diss., University of Chicago, 1964).")
